@@ -110,7 +110,7 @@ use Moo::Role ();
 use List::Util qw/ any /;
 use Sub::Quote qw/ quote_sub /;
 
-our $VERSION = '0.0.12';
+our $VERSION = '0.0.13';
 
 my %Attributes;
 
@@ -184,11 +184,4 @@ sub _process_has {
     ( $name, %opts );
 }
 
-sub _json_ld_fields {
-    my ( $class, $self ) = @_;
-    $Attributes{$class} // [];
-}
-
-1;
-
 1;
